@@ -70,6 +70,7 @@ is_close:{is_close}
             message_log = self.message_log.format(absolute_path=self.absolute_path, content=content, is_close=is_close)
 
             self.sock.sendall(message_log.encode('utf8'))
+            self.sock.sendall("\n".encode('utf8'))
         except Exception:
             # 这里发送失败可能是因为: 服务器进程崩溃, 网络问题.
             # 这里可以尝试不做处理, 避免因为日志组件的异常导致对应服务的异常.
@@ -81,8 +82,8 @@ is_close:{is_close}
     def send(self, message=None):
         caller = getframeinfo(stack()[1][0])
         # DEBUG
-        self.__send(message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
-        # self.pool.submit(self.__send, message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
+        # self.__send(message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
+        self.pool.submit(self.__send, message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
 
     def close(self):
         self.__send(is_close=1)
